@@ -9,7 +9,7 @@ from script_client.const import config as conf
 from script_client.common.common_method import regist_app
 
 
-__version__ = "1.2.1"
+__version__ = "1.2.3"
 
 logger.add(os.sep.join([os.getcwd(), 'logs', 'script_client_{time}.log']),
                rotation="1 days", retention="2 days")
@@ -83,7 +83,7 @@ def _run_webserver():
 
 
 def stop():
-    logger.info(f"script client stop")
+    logger.info(f"关 script client ... ")
     web_server.stop_web_server()
 
 
